@@ -1,21 +1,8 @@
 /*
- *   Copyright (C) 2012, 2013, 2014, 2015 Ivan Cukic <ivan.cukic(at)kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License version 2,
- *   or (at your option) any later version, as published by the Free
- *   Software Foundation
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2012, 2013, 2014, 2015 Ivan Cukic <ivan.cukic(at)kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // Self
 #include "activitymodel.h"
@@ -25,10 +12,10 @@
 #include <QDBusPendingCall>
 #include <QDBusPendingCallWatcher>
 #include <QDebug>
+#include <QFutureWatcher>
 #include <QHash>
 #include <QIcon>
 #include <QList>
-#include <QFutureWatcher>
 #include <QModelIndex>
 
 // KDE
@@ -37,10 +24,10 @@
 #include <kdirwatch.h>
 
 // Boost
-#include <boost/range/algorithm/find_if.hpp>
-#include <boost/range/algorithm/binary_search.hpp>
-#include <boost/range/adaptor/filtered.hpp>
 #include <boost/optional.hpp>
+#include <boost/range/adaptor/filtered.hpp>
+#include <boost/range/algorithm/binary_search.hpp>
+#include <boost/range/algorithm/find_if.hpp>
 
 // Local
 #include "utils/remove_if.h"
@@ -50,11 +37,12 @@
 
 using kamd::utils::continue_with;
 
-
-namespace KActivities {
-namespace Imports {
-
-class ActivityModel::Private {
+namespace KActivities
+{
+namespace Imports
+{
+class ActivityModel::Private
+{
 public:
     DECLARE_RAII_MODEL_UPDATERS(ActivityModel)
 
@@ -62,13 +50,11 @@ public:
      * Returns whether the activity has a desired state.
      * If the state is 0, returns true
      */
-    template <typename T>
-    static inline bool matchingState(InfoPtr activity,
-                                     T states)
+    template<typename T>
+    static inline bool matchingState(InfoPtr activity, T states)
     {
         // Are we filtering activities on their states?
-        if (!states.empty()
-            && !boost::binary_search(states, activity->state())) {
+        if (!states.empty() && !boost::binary_search(states, activity->state())) {
             return false;
         }
 
@@ -79,67 +65,47 @@ public:
      * Searches for the activity.
      * Returns an option(index, iterator) for the found activity.
      */
-    template <typename _Container>
-    static inline
-    boost::optional<
-        std::pair<unsigned int, typename _Container::const_iterator>
-    >
-    activityPosition(const _Container &container, const QString &activityId)
+    template<typename _Container>
+    static inline boost::optional<std::pair<unsigned int, typename _Container::const_iterator>> activityPosition(const _Container &container,
+                                                                                                                 const QString &activityId)
     {
-        using ActivityPosition =
-                decltype(activityPosition(container, activityId));
-        using ContainerElement =
-                typename _Container::value_type;
+        using ActivityPosition = decltype(activityPosition(container, activityId));
+        using ContainerElement = typename _Container::value_type;
 
-        auto position = boost::find_if(container,
-            [&] (const ContainerElement &activity) {
-                return activity->id() == activityId;
-            }
-        );
+        auto position = boost::find_if(container, [&](const ContainerElement &activity) {
+            return activity->id() == activityId;
+        });
 
-        return (position != container.end()) ?
-            ActivityPosition(
-                std::make_pair(position - container.begin(), position)
-            ) :
-            ActivityPosition();
+        return (position != container.end()) ? ActivityPosition(std::make_pair(position - container.begin(), position)) : ActivityPosition();
     }
 
     /**
      * Notifies the model that an activity was updated
      */
-    template <typename _Model, typename _Container>
-    static inline
-    void emitActivityUpdated(_Model *model,
-                             const _Container &container,
-                             QObject *activityInfo, int role)
+    template<typename _Model, typename _Container>
+    static inline void emitActivityUpdated(_Model *model, const _Container &container, QObject *activityInfo, int role)
     {
-        const auto activity = static_cast<Info*> (activityInfo);
+        const auto activity = static_cast<Info *>(activityInfo);
         emitActivityUpdated(model, container, activity->id(), role);
     }
 
     /**
      * Notifies the model that an activity was updated
      */
-    template <typename _Model, typename _Container>
-    static inline
-    void emitActivityUpdated(_Model *model,
-                             const _Container &container,
-                             const QString &activity, int role)
+    template<typename _Model, typename _Container>
+    static inline void emitActivityUpdated(_Model *model, const _Container &container, const QString &activity, int role)
     {
         auto position = Private::activityPosition(container, activity);
 
         if (position) {
-            emit model->dataChanged(
-                model->index(position->first),
-                model->index(position->first),
-                role == Qt::DecorationRole ?
-                    QVector<int> {role, ActivityModel::ActivityIcon} :
-                    QVector<int> {role}
-            );
+            Q_EMIT model->dataChanged(model->index(position->first),
+                                      model->index(position->first),
+                                      role == Qt::DecorationRole ? QVector<int>{role, ActivityModel::ActivityIcon} : QVector<int>{role});
         }
     }
 
-    class BackgroundCache {
+    class BackgroundCache
+    {
     public:
         BackgroundCache()
             : initialized(false)
@@ -147,21 +113,19 @@ public:
         {
             using namespace std::placeholders;
 
-            const QString configFile = QStandardPaths::writableLocation(
-                                           QStandardPaths::GenericConfigLocation) +
-                                       QLatin1Char('/') + plasmaConfig.name();
+            const QString configFile = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QLatin1Char('/') + plasmaConfig.name();
 
             KDirWatch::self()->addFile(configFile);
 
-            connect(KDirWatch::self(), &KDirWatch::dirty,
-                    std::bind(&BackgroundCache::settingsFileChanged, this, _1));
-            connect(KDirWatch::self(), &KDirWatch::created,
-                    std::bind(&BackgroundCache::settingsFileChanged, this, _1));
+            connect(KDirWatch::self(), &KDirWatch::dirty, std::bind(&BackgroundCache::settingsFileChanged, this, _1));
+            connect(KDirWatch::self(), &KDirWatch::created, std::bind(&BackgroundCache::settingsFileChanged, this, _1));
         }
 
         void settingsFileChanged(const QString &file)
         {
-            if (!file.endsWith(plasmaConfig.name())) return;
+            if (!file.endsWith(plasmaConfig.name())) {
+                return;
+            }
 
             plasmaConfig.reparseConfiguration();
 
@@ -219,17 +183,19 @@ public:
 
             QStringList changedBackgrounds;
 
-            for (const auto &cont: plasmaConfigContainments().groupList()) {
-
+            for (const auto &cont : plasmaConfigContainments().groupList()) {
                 auto config = plasmaConfigContainments().group(cont);
                 auto activityId = config.readEntry("activityId", QString());
 
                 // Ignore if it has no assigned activity
-                if (activityId.isEmpty()) continue;
+                if (activityId.isEmpty()) {
+                    continue;
+                }
 
                 // Ignore if we have already found the background
-                if (newBackgrounds.contains(activityId) &&
-                    newBackgrounds[activityId][0] != QLatin1Char('#')) continue;
+                if (newBackgrounds.contains(activityId) && newBackgrounds[activityId][0] != QLatin1Char('#')) {
+                    continue;
+                }
 
                 auto newBackground = backgroundFromConfig(config);
 
@@ -246,22 +212,22 @@ public:
             if (!changedBackgrounds.isEmpty()) {
                 forActivity = newBackgrounds;
 
-                for (auto model: models) {
+                for (auto model : models) {
                     model->backgroundsUpdated(changedBackgrounds);
                 }
             }
         }
 
-        KConfigGroup plasmaConfigContainments() {
+        KConfigGroup plasmaConfigContainments()
+        {
             return plasmaConfig.group("Containments");
         }
 
         QHash<QString, QString> forActivity;
-        QList<ActivityModel*> models;
+        QList<ActivityModel *> models;
 
         bool initialized;
         KConfig plasmaConfig;
-
     };
 
     static BackgroundCache &backgrounds()
@@ -273,20 +239,17 @@ public:
     }
 };
 
-
 ActivityModel::ActivityModel(QObject *parent)
     : QAbstractListModel(parent)
 {
     // Initializing role names for qml
-    connect(&m_service, &Consumer::serviceStatusChanged,
-            this,       &ActivityModel::setServiceStatus);
+    connect(&m_service, &Consumer::serviceStatusChanged, this, &ActivityModel::setServiceStatus);
 
-    connect(&m_service, SIGNAL(activityAdded(QString)),
-            this,       SLOT(onActivityAdded(QString)));
-    connect(&m_service, SIGNAL(activityRemoved(QString)),
-            this,       SLOT(onActivityRemoved(QString)));
-    connect(&m_service, SIGNAL(currentActivityChanged(QString)),
-            this,       SLOT(onCurrentActivityChanged(QString)));
+    connect(&m_service, &KActivities::Consumer::activityAdded, this, [this](const QString &id) {
+        onActivityAdded(id);
+    });
+    connect(&m_service, &KActivities::Consumer::activityRemoved, this, &ActivityModel::onActivityRemoved);
+    connect(&m_service, &KActivities::Consumer::currentActivityChanged, this, &ActivityModel::onCurrentActivityChanged);
 
     setServiceStatus(m_service.serviceStatus());
 
@@ -300,20 +263,17 @@ ActivityModel::~ActivityModel()
 
 QHash<int, QByteArray> ActivityModel::roleNames() const
 {
-    return {
-        {Qt::DisplayRole,     "name"},
-        {Qt::DecorationRole,  "icon"},
+    return {{Qt::DisplayRole, "name"},
+            {Qt::DecorationRole, "icon"},
 
-        {ActivityState,       "state"},
-        {ActivityId,          "id"},
-        {ActivityIcon,        "iconSource"},
-        {ActivityDescription, "description"},
-        {ActivityBackground,  "background"},
-        {ActivityCurrent,     "current"}
-    };
+            {ActivityState, "state"},
+            {ActivityId, "id"},
+            {ActivityIcon, "iconSource"},
+            {ActivityDescription, "description"},
+            {ActivityBackground, "background"},
+            {ActivityCurrent, "current"}};
 }
 
-
 void ActivityModel::setServiceStatus(Consumer::ServiceStatus)
 {
     replaceActivities(m_service.activities());
@@ -330,7 +290,7 @@ void ActivityModel::replaceActivities(const QStringList &activities)
     m_knownActivities.clear();
     m_shownActivities.clear();
 
-    for (const QString &activity: activities) {
+    for (const QString &activity : activities) {
         onActivityAdded(activity, false);
     }
 }
@@ -357,9 +317,8 @@ void ActivityModel::onCurrentActivityChanged(const QString &id)
 {
     Q_UNUSED(id);
 
-    for (const auto &activity: m_shownActivities) {
-        Private::emitActivityUpdated(this, m_shownActivities, activity->id(),
-                                     ActivityCurrent);
+    for (const auto &activity : m_shownActivities) {
+        Private::emitActivityUpdated(this, m_shownActivities, activity->id(), ActivityCurrent);
     }
 }
 
@@ -378,14 +337,10 @@ ActivityModel::InfoPtr ActivityModel::registerActivity(const QString &id)
 
         auto ptr = activityInfo.get();
 
-        connect(ptr,  &Info::nameChanged,
-                this, &ActivityModel::onActivityNameChanged);
-        connect(ptr,  &Info::descriptionChanged,
-                this, &ActivityModel::onActivityDescriptionChanged);
-        connect(ptr,  &Info::iconChanged,
-                this, &ActivityModel::onActivityIconChanged);
-        connect(ptr,  &Info::stateChanged,
-                this, &ActivityModel::onActivityStateChanged);
+        connect(ptr, &Info::nameChanged, this, &ActivityModel::onActivityNameChanged);
+        connect(ptr, &Info::descriptionChanged, this, &ActivityModel::onActivityDescriptionChanged);
+        connect(ptr, &Info::iconChanged, this, &ActivityModel::onActivityIconChanged);
+        connect(ptr, &Info::stateChanged, this, &ActivityModel::onActivityStateChanged);
 
         m_knownActivities.insert(InfoPtr(activityInfo));
 
@@ -401,8 +356,7 @@ void ActivityModel::unregisterActivity(const QString &id)
 
     if (position) {
         if (auto shown = Private::activityPosition(m_shownActivities, id)) {
-            Private::model_remove(this, QModelIndex(), shown->first,
-                                  shown->first);
+            Private::model_remove(this, QModelIndex(), shown->first, shown->first);
             m_shownActivities.erase(shown->second);
         }
 
@@ -413,14 +367,16 @@ void ActivityModel::unregisterActivity(const QString &id)
 void ActivityModel::showActivity(InfoPtr activityInfo, bool notifyClients)
 {
     // Should it really be shown?
-    if (!Private::matchingState(activityInfo, m_shownStates)) return;
+    if (!Private::matchingState(activityInfo, m_shownStates)) {
+        return;
+    }
 
     // Is it already shown?
-    if (boost::binary_search(m_shownActivities, activityInfo,
-                             InfoPtrComparator())) return;
+    if (boost::binary_search(m_shownActivities, activityInfo, InfoPtrComparator())) {
+        return;
+    }
 
-    auto registeredPosition
-        = Private::activityPosition(m_knownActivities, activityInfo->id());
+    auto registeredPosition = Private::activityPosition(m_knownActivities, activityInfo->id());
 
     if (!registeredPosition) {
         qDebug() << "Got a request to show an unknown activity, ignoring";
@@ -435,9 +391,7 @@ void ActivityModel::showActivity(InfoPtr activityInfo, bool notifyClients)
     auto position = m_shownActivities.insert(activityInfoPtr);
 
     if (notifyClients) {
-        unsigned int index =
-            (position.second ? position.first : m_shownActivities.end())
-            - m_shownActivities.begin();
+        unsigned int index = (position.second ? position.first : m_shownActivities.end()) - m_shownActivities.begin();
 
         // qDebug() << m_shownStatesString << " -- MODEL INSERT -- " << index;
         Private::model_insert(this, QModelIndex(), index, index);
@@ -454,29 +408,28 @@ void ActivityModel::hideActivity(const QString &id)
     if (position) {
         // qDebug() << m_shownStatesString << " -- MODEL REMOVE -- "
         //          << position->first;
-        Private::model_remove(this, QModelIndex(),
-            position->first, position->first);
+        Private::model_remove(this, QModelIndex(), position->first, position->first);
         m_shownActivities.erase(position->second);
     }
 }
-
+// clang-format off
 #define CREATE_SIGNAL_EMITTER(What,Role)                                      \
     void ActivityModel::onActivity##What##Changed(const QString &)             \
     {                                                                          \
         Private::emitActivityUpdated(this, m_shownActivities, sender(), Role); \
     }
+// clang-format on
 
-CREATE_SIGNAL_EMITTER(Name,Qt::DisplayRole)
-CREATE_SIGNAL_EMITTER(Description,ActivityDescription)
-CREATE_SIGNAL_EMITTER(Icon,Qt::DecorationRole)
+CREATE_SIGNAL_EMITTER(Name, Qt::DisplayRole)
+CREATE_SIGNAL_EMITTER(Description, ActivityDescription)
+CREATE_SIGNAL_EMITTER(Icon, Qt::DecorationRole)
 
 #undef CREATE_SIGNAL_EMITTER
 
 void ActivityModel::onActivityStateChanged(Info::State state)
 {
     if (m_shownStates.empty()) {
-        Private::emitActivityUpdated(this, m_shownActivities, sender(),
-                                     ActivityState);
+        Private::emitActivityUpdated(this, m_shownActivities, sender(), ActivityState);
 
     } else {
         auto info = findActivity(sender());
@@ -495,9 +448,8 @@ void ActivityModel::onActivityStateChanged(Info::State state)
 
 void ActivityModel::backgroundsUpdated(const QStringList &activities)
 {
-    for (const auto &activity: activities) {
-        Private::emitActivityUpdated(this, m_shownActivities, activity,
-                                     ActivityBackground);
+    for (const auto &activity : activities) {
+        Private::emitActivityUpdated(this, m_shownActivities, activity, ActivityBackground);
     }
 }
 
@@ -506,25 +458,24 @@ void ActivityModel::setShownStates(const QString &states)
     m_shownStates.clear();
     m_shownStatesString = states;
 
-    for (const auto &state: states.split(QLatin1Char(','))) {
-        if (state == QStringLiteral("Running")) {
+    for (const auto &state : states.split(QLatin1Char(','))) {
+        if (state == QLatin1String("Running")) {
             m_shownStates.insert(Running);
 
-        } else if (state == QStringLiteral("Starting")) {
+        } else if (state == QLatin1String("Starting")) {
             m_shownStates.insert(Starting);
 
-        } else if (state == QStringLiteral("Stopped")) {
+        } else if (state == QLatin1String("Stopped")) {
             m_shownStates.insert(Stopped);
 
-        } else if (state == QStringLiteral("Stopping")) {
+        } else if (state == QLatin1String("Stopping")) {
             m_shownStates.insert(Stopping);
-
         }
     }
 
     replaceActivities(m_service.activities());
 
-    emit shownStatesChanged(states);
+    Q_EMIT shownStatesChanged(states);
 }
 
 QString ActivityModel::shownStates() const
@@ -557,13 +508,12 @@ QVariant ActivityModel::data(const QModelIndex &index, int role) const
     case ActivityState:
         return item->state();
 
-    case ActivityIcon:
-        {
-            const QString &icon = item->icon();
+    case ActivityIcon: {
+        const QString &icon = item->icon();
 
-            // We need a default icon for activities
-            return icon.isEmpty() ? QStringLiteral("preferences-activities") : icon;
-        }
+        // We need a default icon for activities
+        return icon.isEmpty() ? QStringLiteral("activities") : icon;
+    }
 
     case ActivityDescription:
         return item->description();
@@ -579,8 +529,7 @@ QVariant ActivityModel::data(const QModelIndex &index, int role) const
     }
 }
 
-QVariant ActivityModel::headerData(int section, Qt::Orientation orientation,
-                                   int role) const
+QVariant ActivityModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
     Q_UNUSED(section);
     Q_UNUSED(orientation);
@@ -591,9 +540,9 @@ QVariant ActivityModel::headerData(int section, Qt::Orientation orientation,
 
 ActivityModel::InfoPtr ActivityModel::findActivity(QObject *ptr) const
 {
-    auto info = boost::find_if(m_knownActivities, [ptr] (const InfoPtr &info) {
-            return ptr == info.get();
-        });
+    auto info = boost::find_if(m_knownActivities, [ptr](const InfoPtr &info) {
+        return ptr == info.get();
+    });
 
     if (info == m_knownActivities.end()) {
         return nullptr;
@@ -602,6 +551,7 @@ ActivityModel::InfoPtr ActivityModel::findActivity(QObject *ptr) const
     }
 }
 
+// clang-format off
 // QFuture<void> Controller::setActivityWhat(id, value)
 #define CREATE_SETTER(What)                                                    \
     void ActivityModel::setActivity##What(                                     \
@@ -609,6 +559,7 @@ ActivityModel::InfoPtr ActivityModel::findActivity(QObject *ptr) const
     {                                                                          \
         continue_with(m_service.setActivity##What(id, value), callback);       \
     }
+// clang-format on
 
 CREATE_SETTER(Name)
 CREATE_SETTER(Description)
@@ -617,8 +568,7 @@ CREATE_SETTER(Icon)
 #undef CREATE_SETTER
 
 // QFuture<bool> Controller::setCurrentActivity(id)
-void ActivityModel::setCurrentActivity(const QString &id,
-                                       const QJSValue &callback)
+void ActivityModel::setCurrentActivity(const QString &id, const QJSValue &callback)
 {
     continue_with(m_service.setCurrentActivity(id), callback);
 }
@@ -651,4 +601,3 @@ void ActivityModel::startActivity(const QString &id, const QJSValue &callback)
 } // namespace KActivities
 
 // #include "activitymodel.moc"
-
